@@ -1,6 +1,7 @@
 """Loss functions for Maximum Likelihood Estimation."""
 from typing import List
 from typing import Tuple
+from typing import Union
 
 import torch
 from ray.rllib import SampleBatch
@@ -19,7 +20,7 @@ class MaximumLikelihood(Loss):
     """Loss function for model learning of single transitions.
 
     Args:
-        model: parametric stochastic model
+        models: parametric stochastic model (single or ensemble)
     """
 
     batch_keys: Tuple[str, str, str] = (
@@ -28,43 +29,19 @@ class MaximumLikelihood(Loss):
         SampleBatch.NEXT_OBS,
     )
 
-    def __init__(self, model: StochasticModel):
-        self.model = model
+    def __init__(self, models: Union[StochasticModel, SME]):
+        if isinstance(models, StochasticModel):
+            # Treat everything as if ensemble
+            models = SME([models])
+        self.models = models
+        self.tag = "nll"
+
+    def compile(self):
+        self.models = torch.jit.script(self.models)
 
     def __call__(self, batch: TensorDict) -> Tuple[Tensor, StatDict]:
         """Compute Maximum Likelihood Estimation (MLE) model loss.
 
-        Returns:
-            A tuple containg a 0d loss tensor and a dictionary of loss
-            statistics
-        """
-        obs, actions, next_obs = get_keys(batch, *self.batch_keys)
-
-        dist_params = self.model(obs, actions)
-        loss = -self.model.log_prob(next_obs, dist_params).mean()
-        if "max_logvar" in dist_params and "min_logvar" in dist_params:
-            loss += 0.01 * dist_params["max_logvar"].sum()
-            loss += -0.01 * dist_params["min_logvar"].sum()
-
-        return loss, {"loss(model)": loss.item()}
-
-
-class ModelEnsembleMLE(Loss):
-    """MLE loss function for ensemble of models.
-
-    Args:
-        models: the list of models
-    """
-
-    batch_keys: Tuple[str, str, str] = MaximumLikelihood.batch_keys
-
-    def __init__(self, models: SME):
-        self.models = models
-        self.tag = "MLE"
-
-    def __call__(self, batch: TensorDict) -> Tuple[Tensor, StatDict]:
-        """Compute Maximum Likelihood Estimation (MLE) loss for each model.
-
         Returns:
             A tuple with a 1d loss tensor containing each model's loss and a
             dictionary of loss statistics
@@ -74,16 +51,13 @@ class ModelEnsembleMLE(Loss):
         )
 
         dist_params = self.models(obs, actions)
-        losses = [-logp.mean() for logp in self.models.log_prob(next_obs, dist_params)]
-        losses_reg = [
-            nll + 0.01 * p["max_logvar"].sum() - 0.01 * p["min_logvar"].sum()
-            if "max_logvar" in p and "min_logvar" in p
-            else nll
-            for nll, p in zip(losses, dist_params)
+        nlls = [-logp.mean() for logp in self.models.log_prob(next_obs, dist_params)]
+        losses = [
+            nll + reg for nll, reg in zip(nlls, self.regularizations(dist_params))
         ]
 
-        info = {f"{self.tag}(models[{i}])": n.item() for i, n in enumerate(losses_reg)}
-        return torch.stack(losses_reg), info
+        info = {f"{self.tag}(models[{i}])": n.item() for i, n in enumerate(nlls)}
+        return torch.stack(losses), info
 
     def expand_foreach_model(self, tensor: Tensor) -> List[Tensor]:
         """Add first dimension to tensor with the size of the model ensemble.
@@ -96,5 +70,35 @@ class ModelEnsembleMLE(Loss):
         """
         return [tensor.clone() for _ in range(len(self.models))]
 
-    def compile(self):
-        self.models = torch.jit.script(self.models)
+    @classmethod
+    def regularizations(cls, params_list: List[TensorDict]) -> List[Tensor]:
+        """Computes logvar bound penalties if needed.
+
+        Args:
+            params_list: List of model distribution parameters
+
+        Returns:
+            List of regularization factors for each model's loss
+        """
+        return list(map(cls.regularize_if_needed, params_list))
+
+    @staticmethod
+    def regularize_if_needed(params: TensorDict) -> Tensor:
+        """Add logvar bound penalty if needed.
+
+        Args:
+            params: Model distribution parameters
+
+        Returns:
+            Regularization factors for model loss
+        """
+        should_regularize = (
+            "max_logvar" in params
+            and params["max_logvar"].requires_grad
+            and "min_logvar" in params
+            and params["min_logvar"].requires_grad
+        )
+        if should_regularize:
+            return 0.01 * params["max_logvar"].sum() - 0.01 * params["min_logvar"].sum()
+
+        return torch.zeros([])
