@@ -1,4 +1,5 @@
 """Implementations of stochastic dynamics models."""
-
+from .builders import build as build_single
 from .builders import build_ensemble
 from .builders import EnsembleSpec
+from .builders import Spec as SingleSpec
